#
# spec file for package OpenColorIO
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define build_flavor %{nil}
%if "%{build_flavor}" == "ocio_tools"
%bcond_without ocio_tools
%else
%bcond_with    ocio_tools
%endif
# Ensure that libyaml-cpp version is the one that is built against
# See boo#1160171
%define yamlrequires %(rpm -q --requires yaml-cpp-devel | grep libyaml || echo aaa_base)
%define so_ver 2_1
%define pkg_name OpenColorIO
%if %{without ocio_tools}
Name:           OpenColorIO
%else
Name:           OpenColorIO-tools
%endif
Version:        2.1.2
Release:        4.2
Summary:        Color Management Solution Geared Towards Motion Picture Production
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
URL:            https://opencolorio.org/
Source0:        https://github.com/AcademySoftwareFoundation/OpenColorIO/archive/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM gcc12_fix.patch asterios.dramis@gmail.com -- Fix compilation with GCC12
Patch0:         gcc12_fix.patch
# PATCH-FIX-OPENSUSE 0001-Fix-detection-of-yaml-cpp-0.8.patch -- temporary solution to detect yaml-cpp 0.8
Patch1:         0001-Fix-detection-of-yaml-cpp-0.8.patch
BuildRequires:  cmake >= 3.12
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libboost_headers-devel
BuildRequires:  libexpat-devel >= 2.2.8
BuildRequires:  liblcms2-devel >= 2.2
BuildRequires:  openexr-devel
BuildRequires:  pkgconfig
BuildRequires:  pystring-devel >= 1.1.3
BuildRequires:  python3-devel
BuildRequires:  python3-pybind11-devel
BuildRequires:  yaml-cpp-devel >= 0.6.3
Recommends:     %{pkg_name}-doc = %{version}
%if %{with ocio_tools}
BuildRequires:  OpenImageIO >= 2.1.9
BuildRequires:  OpenImageIO-devel >= 2.1.9
BuildRequires:  OpenImageIO-plugin-osl
BuildRequires:  OpenShadingLanguage-devel
BuildRequires:  python3-MarkupSafe
BuildRequires:  python3-Sphinx
BuildRequires:  python3-breathe
BuildRequires:  python3-recommonmark
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-sphinx-tabs
BuildRequires:  python3-sphinx_press_theme
BuildRequires:  python3-testresources
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glut)
%endif

%description
OpenColorIO (OCIO) is a color management solution geared towards motion picture
production with an emphasis on visual effects and computer animation.

OCIO is compatible with the Academy Color Encoding Specification (ACES) and is
LUT-format agnostic, supporting many popular formats.

%package devel
Summary:        Development Files for OpenColorIO
Group:          Development/Libraries/C and C++
Requires:       libOpenColorIO%{so_ver} = %{version}
Recommends:     %{pkg_name}-doc = %{version}

%description devel
This package provides development libraries and headers needed to build
software using OpenColorIO.

%package -n %{pkg_name}-doc
Summary:        Documentation for OpenColorIO
Group:          Documentation/Other
BuildArch:      noarch

%description -n %{pkg_name}-doc
This package contains documentation for OpenColorIO.

%package -n libOpenColorIO%{so_ver}
Summary:        Complete Color Management Solution Geared Towards Motion Picture Production
Group:          System/Libraries
Requires:       %{yamlrequires}
# this is unfortunate and a fallout of properly naming the lib after fixing so_ver
Conflicts:      libOpenColorIO2_0 = 2.1.1
Conflicts:      libOpenColorIO2_0 = 2.1.2

%description -n libOpenColorIO%{so_ver}
OpenColorIO (OCIO) is a color management solution geared towards motion picture
production with an emphasis on visual effects and computer animation.

OCIO is compatible with the Academy Color Encoding Specification (ACES) and is
LUT-format agnostic, supporting many popular formats.

%package -n python3-OpenColorIO
Summary:        Python Bindings for OpenColorIO
Group:          Development/Libraries/Python
# python-OpenColorIO was last used at version 1.1.1
Provides:       python-OpenColorIO = %{version}
Obsoletes:      python-OpenColorIO < %{version}

%description -n python3-OpenColorIO
This package contains python bindings for OpenColorIO.

%prep
%autosetup -p1 -n %{pkg_name}-%{version}

# Fix library install location
sed -i 's|DESTINATION lib|DESTINATION %{_lib}|' src/OpenColorIO/CMakeLists.txt

%build
%cmake \
    -DCMAKE_CXX_STANDARD=17 \
    -DCMAKE_SKIP_RPATH=ON \
%ifnarch x86_64
    -DOCIO_USE_SSE=OFF \
%endif
%if %{with ocio_tools}
    -DOCIO_BUILD_DOCS=ON
%else
    -DOCIO_BUILD_APPS=OFF \
    -DOCIO_BUILD_DOCS=OFF
%endif
%cmake_build

%install
%cmake_install

# Remove stray static libs
rm -f %{buildroot}%{_libdir}/*.a

# Move documentation to the right location
mkdir -p %{buildroot}%{_docdir}/%{pkg_name}
cp *.md  %{buildroot}%{_docdir}/%{pkg_name}

# This shouldn't be needed
rm %{buildroot}%{_datadir}/ocio/setup_ocio.sh

%if %{without ocio_tools}
rm -rf %{buildroot}%{_docdir}/%{pkg_name}/
%else
mv %{buildroot}%{_datadir}/doc/OpenColorIO/html/ %{buildroot}%{_docdir}/%{pkg_name}/
rmdir %{buildroot}%{_datadir}/doc/OpenColorIO
rm -rf %{buildroot}%{_libdir}
rm -rf %{buildroot}%{_includedir}
%endif

%post -n libOpenColorIO%{so_ver} -p /sbin/ldconfig
%postun -n libOpenColorIO%{so_ver} -p /sbin/ldconfig

%if %{with ocio_tools}
%files
%license LICENSE
%{_bindir}/*
%doc %{_docdir}/%{pkg_name}/
%exclude %{_docdir}/%{pkg_name}/html/
%{_datadir}/ocio/

%files -n %{pkg_name}-doc
%{_docdir}/%{pkg_name}/html/
%else

%files devel
%{_includedir}/OpenColorIO/
%{_libdir}/pkgconfig/OpenColorIO.pc
%{_libdir}/cmake/OpenColorIO/
%{_libdir}/libOpenColorIO.so

%files -n libOpenColorIO%{so_ver}
%license LICENSE
%{_libdir}/libOpenColorIO.so.*

%files -n python3-OpenColorIO
%license LICENSE
%{python3_sitearch}/PyOpenColorIO.so
%endif

%changelog
* Wed Aug 30 2023 Christophe Marin <christophe@krop.fr>
- Add patch:
  * 0001-Fix-detection-of-yaml-cpp-0.8.patch
* Wed May 31 2023 Hans-Peter Jansen <hpj@urpla.net>
- add OpenShadingLanguage, OpenImageIO-plugin-osl and python3-six
  build deps for tools build
- remove outdated BuildIgnore: libOpenColorIO2_0
* Mon Jul 18 2022 Hans-Peter Jansen <hpj@urpla.net>
- explicitly conflict the wrongly named libs
- don't build tools in basic build stage
* Sun Jul 17 2022 Hans-Peter Jansen <hpj@urpla.net>
- raise c++ standard to 17
- disable rpath, resulting in a hard build failure now
- add opengl deps for gpu support
- broaden stray static libs removal (due to gpu enablement)
* Sat Jul 16 2022 Hans-Peter Jansen <hpj@urpla.net>
- fix so version pkg naming
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.2:
  * Fix half-domain Lut1D issue for certain values above HALF_MAX
  * Python copy support
  * Fix support for ARM64 macOS Python wheels
  * Improve OpenImageIO dependency management of Imath headers
  * Improve CMake and library install step
  * Remove "expat" symbols
  * Improve the GPU unit test framework
  * Improve the OSL integration
  * Propagate Android CMake configuration to external projects
* Thu May 12 2022 Asterios Dramis <asterios.dramis@gmail.com>
- Added a patch "gcc12_fix.patch" to fix compilation with GCC12.
* Tue Mar 15 2022 Dirk Müller <dmueller@suse.com>
- adjust license declaration to be BSD-3-Clause only based on
  licensereview in https://build.opensuse.org/request/show/951516
* Fri Jan 28 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.1:
  * Adds Metal Shading Language generation support to the GPU renderer
  * Adds OpenGL ES generation support to the GPU renderer
  * After Effects plug-in updates
  * Adds Metal support to ociodisplay and enables running GPU tests with Metal backend
  * Fix issue resulting in NaNs when inverting ACES Output Transforms
  * Implement locale-agnostic number parsing
  * Fix issue causing configs to fail validation with certain LUT search paths
  * Python 3.10 macOS wheels
  * Remove extra commas when writing a CDL in CLF file format
  * Fixes Unicode paths on Windows
  * Fix issues with OSL generation and improve the OSL unit test framework
  * Add Python GPU renderer implementation example
  * Improvement to color space metadata in ocioconvert exports
  * Better manage Imath dependency
  * Add ACES 1.3 Gamut Compression implementation
  * Add OpenFX OCIO plug-in framework and examples
  * Add Python wheel generation and support for PyPI
  * Add preliminary support for emitting Open Shading Language
  * Add Imath 3 support for Half dependency and update CI workflow
  * Increment version number for the config file and CTF formats to 2.1
  * Allow apps to use getColorSpaceFromFilePath even for v1 configs and
    deprecate parseColorSpaceFromString
  * Add getDefaultView(display, colorspaceName) method
  * Fix problem rendering to integer pixel layouts when there is a no-op
  * Update CLF test files, add Python scripts for CLF implemenation guide
  * drop fix-armv7.patch, OpenColorIO-openexr3.patch: upstream
* Wed Dec  8 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build on armv6/7:
  * fix-armv7.patch
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  This is an ABI compatible update for the 2.0.x series that includes the
  relevant bug fixes from the 2.1 release.
  Noteworthy bug fixes and enhancements:
  * Allow apps to use getColorSpaceFromFilePath even for v1 configs and
    deprecate parseColorSpaceFromString
  * Fix problem rendering to integer pixel layouts when there is a no-op
  * Update CLF test files, add Python scripts for CLF implemenation guide
- Rebased OpenColorIO-openexr3.patch.
* Tue Sep  7 2021 Marcus Rueckert <mrueckert@suse.de>
- only build the documentation in the ocio_tools case:
  - move BuildRequires into the %%if
  - explicitely disable doc building in the library build case
* Tue Sep  7 2021 Marcus Rueckert <mrueckert@suse.de>
- A probably better fix for solving the build cycle. First build
  will only build all the libraries, 2nd build the cmdline tools
* Tue Sep  7 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not depends on OpenImageIO, in order to break up a build
  cycle (boo#1190237).
* Fri Aug 20 2021 pgajdos@suse.com
- fix build with openexr3
- added patches
  https://aur.archlinux.org/cgit/aur.git/tree/opencolorio-openexr3.patch?h=opencolorio-qfix
  + OpenColorIO-openexr3.patch
* Tue Jul 27 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix 64bit library install location for aarch64 and ppc64* as
  well, not only for x86_64
* Thu Jul 22 2021 Hans-Peter Jansen <hpj@urpla.net>
- provide/obsolete python-OpenColorIO
* Tue Jul 13 2021 Hans-Peter Jansen <hpj@urpla.net>
- Retain the %%{yamlrequires}
* Mon Jul 12 2021 Hans-Peter Jansen <hpj@urpla.net>
- Use %%cmake_build
* Mon Jul  5 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.0.1:
  Unfortunately, it's missing a changelog, check GH release notes:
  https://github.com/AcademySoftwareFoundation/OpenColorIO/releases/tag/v2.0.1
- Removed all patches:
  * OpenColorIO-setuptools.patch
  * 0003-Fix_Linux_compilation.patch
  * 0004-Fix_build_with_GCC-8.patch
  * 0005-Fix_build_with_yaml-cpp0.6.patch
  None of them applied anymore
- Remove tarball crippling, doesn't contain Pygments anymore
- Update build dependencies
- Fix 64bit library install location
- cmake and python devel files disappeared
* Thu Jul  1 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update Requires of devel package to python3-devel
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use python3 to produce the package due to python2 removal
* Wed Jan  8 2020 Dave Plater <davejplater@gmail.com>
- Work around yaml-cpp's bad abi versioning by requiring the version
  it was built against. See boo#1160171
* Fri Apr 19 2019 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 1.1.1:
  * Added optional compatibility for building apps with OpenImageIO
    1.9+
  * Added USE_SSE checks to fix Linux build failure
  * getDisplays() result ordering now matches the active_displays
    config definition or OCIO_ACTIVE_DISPLAYS env var override.
  * Fixed incorrect getDefaultDisplay()/getDefaultView() result
    when OCIO_ACTIVE_DISPLAYS or OCIO_ACTIVE_VIEWS env vars are
    unset.
  * Fixed Windows-specific GetEnv() bug
  * Fixed Windows and MacOS CI failure cases
  * Updated mail list URLs to aswf.io domain
  From version 1.1.0:
  * libc++ build fixes
  * Added support for YAML > 5.0.1
  * YAML and TinyXML patch fixes
  * Clang visibility fix
  * Added write support for Truelight LUTs
  * Improved OCIOYaml
  * Python string corruption fix
  * Added support for CDL
  * Updated documentation
  * Added args/kwargs support to Python MatrixTransform
  * Added description field to Look objects
  * Improved Python 3 compatibility
  * CSP file read fix
  * Added Linux, MacOS, and Windows continuos integration
  * Improved 1D LUT extrapolation
  * Improved 1D LUT negative handling
  * Improved Windows build system
  * Improved cross-platform build system
  * Undefined role crash fix
  * After Effects plugin updated
  * Added reference Photoshop plugin
  * Added reference Docker image
- Added the following patches:
  * OpenColorIO-setuptools.patch (Use external python-setuptools
    for building)
  * 0003-Fix_Linux_compilation.patch
  * 0004-Fix_build_with_GCC-8.patch
  * 0005-Fix_build_with_yaml-cpp0.6.patch
- Added new build requirements libboost_headers-devel and
  python-setuptools.
- Removed support for openSUSE <= 12.2.
* Sat Jan 31 2015 asterios.dramis@gmail.com
- Update to version 1.0.9:
  * CDL cccid supports both named id and index lookups
  * ociobakelut / ocioconvert updates
  * FreeBSD compile dixes
  * FileTransform disk cache allows concurrent disk lookups
  * CSP windows fix
  * Python 3 support
  * Fix envvar abs/relative path testing
  * Can explicitly declare config envvars
  * gcc44 compile warning fixes
- Updated crippled tarball instructions (RegexMatcher.ns2 no longer exists).
- Added new build requirement python-MarkupSafe.
* Sat Jul  6 2013 asterios.dramis@gmail.com
- Use internal yaml-cpp until OpenColorIO is ported to yaml-cpp >= 0.5.0
  currently in Factory.
* Wed May 22 2013 asterios.dramis@gmail.com
- Updated license to "BSD-3-Clause and GPL-2.0+".
- Removed non OSS licensed files from source package - use a crippled tarball
  (bnc#821203).
* Fri Mar 22 2013 asterios.dramis@gmail.com
- Use a proper source URL.
* Thu Mar  7 2013 asterios.dramis@gmail.com
- Build the doc subpackage as noarch.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Use external yaml-cpp library only for openSUSE > 12.2.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Initial release (version 1.0.8).
